@@ -1,10 +1,11 @@
-from typing import Any
+from typing import Any, final
 from inspect import stack
 
-__version__ = "1.1.1"
+__version__ = "1.2.1"
 
 
-class ProtectedDict(dict):
+class _PyattrDict(dict):
+    @final
     def __pyattr_check(self, __key: str, class_object: object, i: int = 3) -> str:
         try:
             caller_class = stack()[i][0].f_locals["self"].__class__.__name__
@@ -39,14 +40,16 @@ class ProtectedDict(dict):
 
         return __key
 
+    @final
     def __getitem__(self, __key: str, class_object: object) -> Any:
         return super().__getitem__(self.__pyattr_check(__key, class_object))
 
+    @final
     def __setitem__(self, __key: str, __value: str, class_object: object) -> None:
         super().__setitem__(self.__pyattr_check(__key, class_object), __value)
 
 
-class Protected(ProtectedDict):
+class Pyattr(_PyattrDict):
     def __init__(self, **kwargs) -> None:
         object.__setattr__(
             self, "pyattr_class_object", stack()[1][0].f_locals["__class__"]
@@ -54,11 +57,12 @@ class Protected(ProtectedDict):
 
         super().update(kwargs)
 
+    @final
     def __getattribute__(self, __name: str) -> Any:
         try:
             obj = object.__getattribute__(self, __name)
 
-            if __name in ["__class__", "_ProtectedDict__pyattr_check"]:
+            if __name in ["__class__", "_PyattrDict__pyattr_check"]:
                 return obj
         except AttributeError:
             pass
@@ -67,6 +71,7 @@ class Protected(ProtectedDict):
             __name, object.__getattribute__(self, "pyattr_class_object")
         )
 
+    @final
     def __setattr__(self, __name: str, __value: Any) -> None:
         return super().__setitem__(
             __name, __value, object.__getattribute__(self, "pyattr_class_object")
